"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var certificate_1 = require("../data/certificate/certificate");
var types_1 = require("../types");
var payload21_1 = require("../data/payload/normal/payload21");
var payload22_1 = require("../data/payload/normal/payload22");
var firstQRIndexes = [1, 2, 3];
var secondQRIndexes = [4, 5];
var QRCodeContainer = /** @class */ (function () {
    function QRCodeContainer() {
        var _this = this;
        this.firstQRCodes = [];
        this.secondQRCodes = [];
        this.push = function (qrCode) {
            _this.validate(qrCode);
            if (qrCode.structuredAppend.N === 3) {
                _this.firstQRCodes.push(qrCode);
            }
            else if (qrCode.structuredAppend.N === 2) {
                _this.secondQRCodes.push(qrCode);
            }
        };
        this.validate = function (qrCode) {
            if (!qrCode.structuredAppend) {
                throw new types_1.InvalidQRCode('This is not structured append QR code');
            }
            else if (!_this.equalParity(qrCode)) {
                throw new types_1.InvalidQRCode('This is not the part of read QR codes');
            }
            else if (_this.isRead(qrCode)) {
                throw new types_1.ReadQRCode('This QR code is already read');
            }
            else if (qrCode.structuredAppend.M === 0 && qrCode.data.split('/')[0] !== '2') {
                throw new types_1.InvalidQRCode('Cannot read this version of QR code');
            }
        };
    }
    Object.defineProperty(QRCodeContainer.prototype, "missingIndex", {
        get: function () {
            var _this = this;
            return firstQRIndexes.concat(secondQRIndexes).filter(function (index) { return _this.readIndex.indexOf(index) === -1; });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainer.prototype, "isCompleted", {
        get: function () {
            return this.missingIndex.length === 0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainer.prototype, "result", {
        get: function () {
            if (this.isCompleted) {
                var firstQRCode = new payload21_1.default(this.firstQRCodes);
                var secondQRCode = new payload22_1.default(this.secondQRCodes);
                return new certificate_1.default(firstQRCode.carIdentifierLocation, firstQRCode.carTypeNumberAndCategoryNumber, firstQRCode.expiresAt, firstQRCode.registeredAt, firstQRCode.model, firstQRCode.frontFrontAxleWeight, firstQRCode.frontRearAxleWeight, firstQRCode.rearFrontAxleWeight, firstQRCode.rearRearAxleWeight, firstQRCode.noiseRegulation, firstQRCode.emissionNoiseRegulation, firstQRCode.driveSystem, firstQRCode.measuredOpacimeter, firstQRCode.measuredNoxAndPm, firstQRCode.nox, firstQRCode.pm, firstQRCode.fuelType, secondQRCode.number, secondQRCode.numberType, secondQRCode.identifier, secondQRCode.engineModel, secondQRCode.sheetType);
            }
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainer.prototype, "readIndex", {
        get: function () {
            return this.firstQRCodes.map(function (qrCode) { return qrCode.structuredAppend.M; })
                .concat(this.secondQRCodes.map(function (qrCode) { return qrCode.structuredAppend.M; }).map(function (index) { return index + 3; }));
        },
        enumerable: false,
        configurable: true
    });
    QRCodeContainer.prototype.isRead = function (qrCode) {
        var readFirst = qrCode.structuredAppend.N === 3 && this.readIndex.includes(qrCode.structuredAppend.M);
        var readSecond = qrCode.structuredAppend.N === 2 && this.readIndex.includes(qrCode.structuredAppend.M + 3);
        return readFirst || readSecond;
    };
    QRCodeContainer.prototype.equalParity = function (qrCode) {
        var _a, _b;
        if (qrCode.structuredAppend.N === 3) {
            var parity = (_a = this.firstQRCodes[0]) === null || _a === void 0 ? void 0 : _a.structuredAppend.parity;
            return !parity || parity === qrCode.structuredAppend.parity;
        }
        else if (qrCode.structuredAppend.N === 2) {
            var parity = (_b = this.secondQRCodes[0]) === null || _b === void 0 ? void 0 : _b.structuredAppend.parity;
            return !parity || parity === qrCode.structuredAppend.parity;
        }
        return false;
    };
    return QRCodeContainer;
}());
exports.default = QRCodeContainer;
//# sourceMappingURL=qrCodeContainer.js.map