"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var keiCertificate_1 = require("../data/certificate/keiCertificate");
var types_1 = require("../types");
var payload22_1 = require("../data/payload/kei/payload22");
var payload31_1 = require("../data/payload/kei/payload31");
var payload51_1 = require("../data/payload/kei/payload51");
var payload61_1 = require("../data/payload/kei/payload61");
var payload71_1 = require("../data/payload/kei/payload71");
var qrTypeVersions = ['71', '61', '51', '31', '22'];
var QRCodeContainerKei = /** @class */ (function () {
    function QRCodeContainerKei() {
        var _this = this;
        this.qrCodes = [];
        this.push = function (qrCode) {
            _this.validate(qrCode);
            _this.qrCodes.push(qrCode);
        };
        this.validate = function (qrCode) {
            if (qrCode.data.split('/')[0] !== 'K') {
                throw new types_1.InvalidQRCode('This is not a Kei QR code');
            }
            else if (!qrTypeVersions.includes(qrCode.data.split('/')[1])) {
                throw new types_1.InvalidQRCode('Cannot read this version of Kei QR code');
            }
            else if (_this.readQRTypeVersions.includes(qrCode.data.split('/')[1])) {
                throw new types_1.ReadQRCode('This QR code is already read');
            }
        };
    }
    Object.defineProperty(QRCodeContainerKei.prototype, "missingIndex", {
        get: function () {
            var _this = this;
            return qrTypeVersions
                .map(function (index) { return _this.readQRTypeVersions.indexOf(index) === -1 ? qrTypeVersions.indexOf(index) + 1 : null; })
                .filter(function (index) { return index !== null; });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainerKei.prototype, "isCompleted", {
        get: function () {
            return this.missingIndex.length === 0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainerKei.prototype, "result", {
        get: function () {
            if (this.isCompleted) {
                var payload22 = new payload22_1.default(this.qrCodes.find(function (qrCode) { return qrCode.data.split('/')[1] === '22'; }));
                var payload31 = new payload31_1.default(this.qrCodes.find(function (qrCode) { return qrCode.data.split('/')[1] === '31'; }));
                var payload51 = new payload51_1.default(this.qrCodes.find(function (qrCode) { return qrCode.data.split('/')[1] === '51'; }));
                var payload61 = new payload61_1.default(this.qrCodes.find(function (qrCode) { return qrCode.data.split('/')[1] === '61'; }));
                var payload71 = new payload71_1.default(this.qrCodes.find(function (qrCode) { return qrCode.data.split('/')[1] === '71'; }));
                return new keiCertificate_1.default(payload31.carIdentifierLocation, payload31.carTypeNumberAndCategoryNumber, payload31.expiresAt, payload31.registeredAt, payload31.model, payload31.frontFrontAxleWeight, payload31.frontRearAxleWeight, payload31.rearFrontAxleWeight, payload31.rearRearAxleWeight, payload31.noiseRegulation, payload31.emissionNoiseRegulation, payload31.driveSystem, payload31.measuredOpacimeter, payload31.measuredNoxAndPm, payload31.nox, payload31.pm, '01', payload22.number, payload22.numberType, payload22.identifier, payload22.engineModel, payload22.sheetType, payload61.ownerAddress, payload51.ownerName, payload71.use, payload71.purpose, payload71.shape, payload71.capacity1, payload71.capacity2, payload71.maxCarrying1, payload71.maxCarrying2, payload71.weight1, payload71.weight2, payload71.code, payload71.mileage, payload71.mileageType);
            }
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainerKei.prototype, "readQRTypeVersions", {
        get: function () {
            return this.qrCodes.map(function (qrCode) { return qrCode.data.split('/')[1]; });
        },
        enumerable: false,
        configurable: true
    });
    return QRCodeContainerKei;
}());
exports.default = QRCodeContainerKei;
//# sourceMappingURL=qrCodeContainerKei.js.map