"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var types_1 = require("../types");
var payload22_1 = require("../data/payload/kei/payload22");
var payload31_1 = require("../data/payload/kei/payload31");
var keiOldCertificate_1 = require("../data/certificate/keiOldCertificate");
var qrTypeVersions = ['31', '22'];
var QRCodeContainerKeiOld = /** @class */ (function () {
    function QRCodeContainerKeiOld() {
        var _this = this;
        this.qrCodes = [];
        this.push = function (qrCode) {
            _this.validate(qrCode);
            _this.qrCodes.push(qrCode);
        };
        this.validate = function (qrCode) {
            if (qrCode.data.split('/')[0] !== 'K') {
                throw new types_1.InvalidQRCode('This is not a Kei QR code');
            }
            else if (!qrTypeVersions.includes(qrCode.data.split('/')[1])) {
                throw new types_1.InvalidQRCode('Cannot read this version of Kei QR code');
            }
            else if (_this.readQRTypeVersions.includes(qrCode.data.split('/')[1])) {
                throw new types_1.ReadQRCode('This QR code is already read');
            }
        };
    }
    Object.defineProperty(QRCodeContainerKeiOld.prototype, "missingIndex", {
        get: function () {
            var _this = this;
            return qrTypeVersions
                .map(function (index) { return _this.readQRTypeVersions.indexOf(index) === -1 ? qrTypeVersions.indexOf(index) + 1 : null; })
                .filter(function (index) { return index !== null; });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainerKeiOld.prototype, "isCompleted", {
        get: function () {
            return this.missingIndex.length === 0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainerKeiOld.prototype, "result", {
        get: function () {
            if (this.isCompleted) {
                var payload22 = new payload22_1.default(this.qrCodes.find(function (qrCode) { return qrCode.data.split('/')[1] === '22'; }));
                var payload31 = new payload31_1.default(this.qrCodes.find(function (qrCode) { return qrCode.data.split('/')[1] === '31'; }));
                return new keiOldCertificate_1.default(payload31.carIdentifierLocation, payload31.carTypeNumberAndCategoryNumber, payload31.expiresAt, payload31.registeredAt, payload31.model, payload31.frontFrontAxleWeight, payload31.frontRearAxleWeight, payload31.rearFrontAxleWeight, payload31.rearRearAxleWeight, payload31.noiseRegulation, payload31.emissionNoiseRegulation, payload31.driveSystem, payload31.measuredOpacimeter, payload31.measuredNoxAndPm, payload31.nox, payload31.pm, '01', payload22.number, payload22.numberType, payload22.identifier, payload22.engineModel, payload22.sheetType);
            }
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(QRCodeContainerKeiOld.prototype, "readQRTypeVersions", {
        get: function () {
            return this.qrCodes.map(function (qrCode) { return qrCode.data.split('/')[1]; });
        },
        enumerable: false,
        configurable: true
    });
    return QRCodeContainerKeiOld;
}());
exports.default = QRCodeContainerKeiOld;
//# sourceMappingURL=qrCodeContainerKeiOld.js.map